@@ -131,6 +131,7 @@ class GuildIterator(_AsyncIterator['Guild']):
         self._filter = None
 
         self.get_guilds = self.bot.http.get_guilds
+        self.get_guild_channels = self.bot.http.get_guild_channels
         self.guilds = asyncio.Queue()
 
         if self.before and self.after:
@@ -159,10 +160,10 @@ class GuildIterator(_AsyncIterator['Guild']):
         self.retrieve = r
         return r > 0
 
-    def create_guild(self, data):
+    def create_guild(self, data, channels):
         from .guild import Guild
 
-        return Guild(data=data)
+        return Guild(data=data, channels=channels)
 
     async def fill_guilds(self):
         if self._get_retrieve():
@@ -174,7 +175,8 @@ class GuildIterator(_AsyncIterator['Guild']):
                 data = filter(self._filter, data)
 
             for element in data:
-                await self.guilds.put(self.create_guild(element))
+                channels = await self.get_guild_channels(element['id'])
+                await self.guilds.put(self.create_guild(element, channels=channels))
 
     async def _retrieve_guilds(self, retrieve) -> List[Guild]:
         """Retrieve guilds and update next parameters."""
@@ -196,4 +198,4 @@ class GuildIterator(_AsyncIterator['Guild']):
         if len(data):
             if self.limit is not None:
                 self.limit -= retrieve
-        return data
\ No newline at end of file
+        return data
